@@ -6,8 +6,6 @@ from copy import copy, deepcopy
 from collections import defaultdict
 from typing import Mapping, Tuple, Type
 from linkml_runtime.utils.namespaces import Namespaces
-from linkml_runtime.utils.context_utils import parse_import_map
-from linkml_runtime.linkml_model.meta import *
 from deprecated.classic import deprecated
 from linkml_runtime.utils.context_utils import parse_import_map
 from linkml_runtime.linkml_model.meta import *
@@ -355,7 +353,7 @@ class SchemaView(object):
         """
         ix = self.element_by_schema_map()
         if element_name not in ix:
-            raise Exception(f'Element {element_name} not in any schema')
+            raise ValueError(f'Element {element_name} not in any schema')
         return ix[element_name]
 
     @lru_cache()
@@ -380,7 +378,7 @@ class SchemaView(object):
         """
         c = self.all_classes(imports).get(class_name, None)
         if strict and c is None:
-            raise Exception(f'No such class as "{class_name}"')
+            raise ValueError(f'No such class as "{class_name}"')
         else:
             return c
 
@@ -402,7 +400,7 @@ class SchemaView(object):
                     slot.from_schema = c.from_schema
                     slot.owner = c.name
         if strict and slot is None:
-            raise Exception(f'No such slot as "{slot_name}"')
+            raise ValueError(f'No such slot as "{slot_name}"')
         return slot
 
     @lru_cache()
@@ -414,7 +412,7 @@ class SchemaView(object):
         """
         s = self.all_subsets(imports).get(subset_name, None)
         if strict and s is None:
-            raise Exception(f'No such subset as "{subset_name}"')
+            raise ValueError(f'No such subset as "{subset_name}"')
         else:
             return s
 
@@ -427,7 +425,7 @@ class SchemaView(object):
         """
         e = self.all_enums(imports).get(enum_name, None)
         if strict and e is None:
-            raise Exception(f'No such subset as "{enum_name}"')
+            raise ValueError(f'No such subset as "{enum_name}"')
         else:
             return e
 
@@ -440,7 +438,7 @@ class SchemaView(object):
         """
         t = self.all_types(imports).get(type_name, None)
         if strict and t is None:
-            raise Exception(f'No such subset as "{type_name}"')
+            raise ValueError(f'No such subset as "{type_name}"')
         else:
             return t
 
@@ -472,7 +470,7 @@ class SchemaView(object):
         :param mixins: include mixins (default is True)
         :return: all direct parent slot names (is_a and mixins)
         """
-        s = self.get_slot(slot_name, imports)
+        s = self.get_slot(slot_name, imports, strict=True)
         return self._parents(s, imports, mixins, is_a)
 
     @lru_cache()
@@ -651,12 +649,12 @@ class SchemaView(object):
             uri = e.uri
             e_name = underscore(e.name)
         else:
-            raise Exception(f'Must be class or slot or type: {e}')
+            raise ValueError(f'Must be class or slot or type: {e}')
         if uri is None or native:
             if e.from_schema is not None:
                 schema = next(sc for sc in self.schema_map.values() if sc.id == e.from_schema)
                 if schema == None:
-                    raise Exception(f'Cannot find {e.from_schema} in schema_map')
+                    raise ValueError(f'Cannot find {e.from_schema} in schema_map')
             else:
                 logging.warning(f'from_schema not populated for element {e.name}')
                 schema = self.schema_map[self.in_schema(e.name)]
@@ -709,7 +707,7 @@ class SchemaView(object):
 
         """
         applicable_elements = []
-        elements = self.all_element()
+        elements = self.all_elements()
         for category, category_element in elements.items():
             if hasattr(category_element, 'id_prefixes') and prefix in category_element.id_prefixes:
                 applicable_elements.append(category_element.name)
@@ -904,7 +902,7 @@ class SchemaView(object):
             #    if getattr(slot, metaslot_name, None):
             #        setattr(islot, metaslot_name, deepcopy(getattr(slot, metaslot_name)))
         else:
-            raise Exception(f'No such slot: {slot_name} and no attribute by that name in ancestors of {class_name}')
+            raise ValueError(f'No such slot: {slot_name} and no attribute by that name in ancestors of {class_name}')
 
         COMBINE = {
             'maximum_value': lambda x, y: min(x, y),
@@ -985,16 +983,36 @@ class SchemaView(object):
         return c
 
     @lru_cache()
-    def get_identifier_slot(self, cn: CLASS_NAME, imports=True) -> Optional[SlotDefinition]:
+    def get_identifier_slot(self, cn: CLASS_NAME, use_key=False, imports=True) -> Optional[SlotDefinition]:
         """
+        Find the slot that is the identifier for the given class
+
         :param cn: class name
         :param imports:
-        :return: name of slot that acts as identifier for the given class
+        :return: name of slot that acts as identifier
         """
         for sn in self.class_slots(cn, imports=imports):
             s = self.induced_slot(sn, cn, imports=imports)
             if s.identifier:
                 return s
+        if use_key:
+            return self.get_key_slot(cn, imports=imports)
+        else:
+            return None
+
+    @lru_cache()
+    def get_key_slot(self, cn: CLASS_NAME, imports=True) -> Optional[SlotDefinition]:
+        """
+        Find the slot that is the key for the given class
+
+        :param cn: class name
+        :param imports:
+        :return: name of slot that acts as key
+        """
+        for sn in self.class_slots(cn, imports=imports):
+            s = self.induced_slot(sn, cn, imports=imports)
+            if s.key:
+                return s
         return None
 
     @lru_cache()
